@@ -1,6 +1,6 @@
-/* $Id: tooltips.hpp 23842 2008-02-16 08:47:16Z mordante $ */
+/* $Id: tooltips.hpp 36823 2009-07-11 22:24:28Z soliton $ */
 /*
-   Copyright (C) 2003 - 2008 by David White <dave@whitevine.net>
+   Copyright (C) 2003 - 2009 by David White <dave@whitevine.net>
    Part of the Battle for Wesnoth Project http://www.wesnoth.org/
 
    This program is free software; you can redistribute it and/or modify
@@ -31,7 +31,7 @@ struct manager
 
 void clear_tooltips();
 void clear_tooltips(const SDL_Rect& rect);
-void add_tooltip(const SDL_Rect& rect, const std::string& message);
+void add_tooltip(const SDL_Rect& rect, const std::string& message, const SDL_Color& color = font::NORMAL_COLOUR);
 void process(int mousex, int mousey);
 
 }
